@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Log::Dispatchouli;
 # ABSTRACT: a simple wrapper around Log::Dispatch
-$Log::Dispatchouli::VERSION = '2.013'; # TRIAL
+$Log::Dispatchouli::VERSION = '2.020'; # TRIAL
 use Carp ();
 use File::Spec ();
 use Log::Dispatch;
@@ -123,6 +123,7 @@ our @CARP_NOT = qw(Log::Dispatchouli::Proxy);
 #pod                 fatal log messages will not be logged to these
 #pod                 (default: stderr)
 #pod   config_id   - a name for this logger's config; rarely needed!
+#pod   syslog_socket - a value for Sys::Syslog's "socket" arg; default: "native"
 #pod
 #pod The log path is either F</tmp> or the value of the F<DISPATCHOULI_PATH> env var.
 #pod
@@ -154,8 +155,8 @@ sub new {
     $pid_prefix
     ? (
         callbacks => sub {
-	  "[$$] ". {@_}->{message}
-	},
+          "[$$] ". {@_}->{message}
+        },
       )
     : ()
   );
@@ -202,7 +203,7 @@ sub new {
         facility  => $arg->{facility},
         ident     => $ident,
         logopt    => 'pid',
-        socket    => 'native',
+        socket    => $arg->{syslog_socket} || 'native',
         callbacks => sub {
           ( my $m = {@_}->{message} ) =~ s/\n/<LF>/g;
           $m
@@ -223,34 +224,48 @@ sub new {
     );
   }
 
-  DEST: for my $dest (qw(err out)) {
-    next DEST unless $arg->{"to_std$dest"};
-    require Log::Dispatch::Screen;
-    $log->add(
-      Log::Dispatch::Screen->new(
-        name      => "std$dest",
-        min_level => 'debug',
-        stderr    => ($dest eq 'err' ? 1 : 0),
-        callbacks => sub { +{@_}->{message} . "\n" },
-        ($quiet_fatal{"std$dest"} ? (max_level => 'info') : ()),
-      ),
-    );
-  }
-
   $self->{dispatcher} = $log;
   $self->{prefix}     = $arg->{prefix};
   $self->{ident}      = $ident;
   $self->{config_id}  = $config_id;
 
+  DEST: for my $dest (qw(err out)) {
+    next DEST unless $arg->{"to_std$dest"};
+    my $method = "enable_std$dest";
+
+    $self->$method;
+  }
+
   $self->{debug}  = exists $arg->{debug}
                   ? ($arg->{debug} ? 1 : 0)
                   : ($self->env_value('DEBUG') ? 1 : 0);
+  $self->{muted}  = $arg->{muted};
 
-  $self->{fail_fatal} = exists $arg->{fail_fatal} ? $arg->{fail_fatal} : 1;
+  $self->{quiet_fatal} = \%quiet_fatal;
+  $self->{fail_fatal}  = exists $arg->{fail_fatal} ? $arg->{fail_fatal} : 1;
 
   return $self;
 }
 
+for my $dest (qw(out err)) {
+  my $name = "std$dest";
+  my $code = sub {
+    return if $_[0]->dispatcher->output($name);
+    $_[0]->dispatcher->add(
+      $_[0]->stdio_dispatcher_class->new(
+        name      => "std$dest",
+        min_level => 'debug',
+        stderr    => ($dest eq 'err' ? 1 : 0),
+        callbacks => sub { +{@_}->{message} . "\n" },
+        ($_[0]{quiet_fatal}{"std$dest"} ? (max_level => 'info') : ()),
+      ),
+    );
+  };
+
+  no strict 'refs';
+  *{"enable_std$dest"} = $code;
+}
+
 #pod =method log
 #pod
 #pod   $logger->log(@messages);
@@ -592,12 +607,15 @@ sub clear_events {
 #pod
 #pod =cut
 
+sub proxy_class {
+  return 'Log::Dispatchouli::Proxy';
+}
+
 sub proxy {
   my ($self, $arg) = @_;
   $arg ||= {};
 
-  require Log::Dispatchouli::Proxy;
-  Log::Dispatchouli::Proxy->_new({
+  $self->proxy_class->_new({
     parent => $self,
     logger => $self,
     proxy_prefix => $arg->{proxy_prefix},
@@ -626,6 +644,19 @@ sub logger { $_[0] }
 
 sub dispatcher   { $_[0]->{dispatcher} }
 
+#pod =method stdio_dispatcher_class
+#pod
+#pod This method is an experimental feature to allow you to pick an alternate
+#pod dispatch class for stderr and stdio.  By default, Log::Dispatch::Screen is
+#pod used.
+#pod
+#pod =cut
+
+sub stdio_dispatcher_class {
+  require Log::Dispatch::Screen;
+  return 'Log::Dispatch::Screen';
+}
+
 #pod =head1 METHODS FOR API COMPATIBILITY
 #pod
 #pod To provide compatibility with some other loggers, most specifically
@@ -693,7 +724,7 @@ Log::Dispatchouli - a simple wrapper around Log::Dispatch
 
 =head1 VERSION
 
-version 2.013
+version 2.020
 
 =head1 SYNOPSIS
 
@@ -762,6 +793,7 @@ Valid arguments are:
                 fatal log messages will not be logged to these
                 (default: stderr)
   config_id   - a name for this logger's config; rarely needed!
+  syslog_socket - a value for Sys::Syslog's "socket" arg; default: "native"
 
 The log path is either F</tmp> or the value of the F<DISPATCHOULI_PATH> env var.
 
@@ -867,6 +899,12 @@ current logger will not throw an exception, and will simply do no thing.
 This returns the underlying Log::Dispatch object.  This is not the method
 you're looking for.  Move along.
 
+=head2 stdio_dispatcher_class
+
+This method is an experimental feature to allow you to pick an alternate
+dispatch class for stderr and stdio.  By default, Log::Dispatch::Screen is
+used.
+
 =head1 LOGGER PREFIX
 
 Log messages may be prepended with information to set context.  This can be set
@@ -1041,7 +1079,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Christopher J. Madsen Dagfinn Ilmari Mannsåker George Hartzell Matt Phillips Olivier Mengué Randy Stauner Sawyer X
+=for stopwords Christopher J. Madsen Dagfinn Ilmari Mannsåker Dan Book George Hartzell Jon Stuart Matt Phillips Olivier Mengué Randy Stauner Sawyer X
 
 =over 4
 
@@ -1055,10 +1093,18 @@ Dagfinn Ilmari Mannsåker <ilmari@ilmari.org>
 
 =item *
 
+Dan Book <grinnz@gmail.com>
+
+=item *
+
 George Hartzell <hartzell@alerce.com>
 
 =item *
 
+Jon Stuart <jon@fastmailteam.com>
+
+=item *
+
 Matt Phillips <mattp@cpan.org>
 
 =item *
@@ -1077,7 +1123,7 @@ Sawyer X <xsawyerx@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo SIGNES.
+This software is copyright (c) 2020 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
